<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Copy</source>
        <translation type="unfinished">Copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Rename</source>
        <translation type="unfinished">Renombrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Move</source>
        <translation type="unfinished">Mover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Delete</source>
        <translation type="unfinished">Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Edit</source>
        <translation type="unfinished">Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Share</source>
        <translation type="unfinished">Compartir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Compress</source>
        <translation type="unfinished">Comprimir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Documents</source>
        <translation type="unfinished">Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Images</source>
        <translation type="unfinished">Imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Camera</source>
        <translation type="unfinished">Cámara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Sounds</source>
        <translation type="unfinished">Sonidos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Videos</source>
        <translation type="unfinished">Videos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Added to Clipboard</source>
        <translation type="unfinished">Agregado al Portapapeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation type="unfinished">ERROR: Nada seleccionado para pegar</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>You don't have permissions to proceed.</source>
        <translation type="unfinished">No tiene permisos para proceder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>About</source>
        <translation type="unfinished">Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Broken Symlink!</source>
        <translation type="unfinished">Enlace perdido!</translation>
    </message>
</context>
<context>
    <name>BookWindow</name>
    <message>
        <location filename="../bookwindow.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation type="unfinished">Favoritos</translation>
    </message>
</context>
<context>
    <name>Home</name>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Home folder</source>
        <translation type="unfinished">Carpeta de inicio</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Compress destination</source>
        <translation type="unfinished">Destino de compresión</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Extract destination</source>
        <translation type="unfinished">Destino de extracción</translation>
    </message>
</context>
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../clipboard.cpp" line="10"/>
        <source>Clipboard</source>
        <translation type="unfinished">Portapapeles</translation>
    </message>
</context>
<context>
    <name>Bookmarks</name>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation type="unfinished">Favoritos</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Delete</source>
        <translation type="unfinished">Eliminar</translation>
    </message>
</context>
<context>
    <name>ToolsDialog</name>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Tools</source>
        <translation type="unfinished">Herramientas</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Add to Bookmarks</source>
        <translation type="unfinished">Agregar a Favoritos</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new folder</source>
        <translation type="unfinished">Crear nueva carpeta</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new document</source>
        <translation type="unfinished">Crear nuevo documento</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Open terminal here</source>
        <translation type="unfinished">Abrir terminal aquí</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Sort</source>
        <translation type="unfinished">Ordenar</translation>
    </message>
</context>
<context>
    <name>Share</name>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Share</source>
        <translation type="unfinished">Compartir</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via bluetooth</source>
        <translation type="unfinished">Enviar por bluetooth</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via e-mail</source>
        <translation type="unfinished">Enviar por e-mail</translation>
    </message>
</context>
<context>
    <name>QtCopyDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1 of %2 completed</source>
        <translation type="unfinished">%1 de %2 completado</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Warning</source>
        <translation type="unfinished">Advertencia</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation type="unfinished">Advertencia</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source doesn&apos;t exist.</source>
        <translation type="unfinished">No existe el archivo fuente.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>No enough space for copy the file.</source>
        <translation type="unfinished">No hay espacio para copiar el archivo.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source file is a directory. Omitting source directory.</source>
        <translation type="unfinished">El archivo fuente es una carpeta. Omitiendo carpeta.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source directory is a file. Omitting source file.</source>
        <translation type="unfinished">La carpeta fuente es un archivo. Omitiendo archivo.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Path to destination does not exist.</source>
        <translation type="unfinished">No existe la carpeta destino.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create destination directory.</source>
        <translation type="unfinished">No se puede crear la carpeta destino.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open source file. Please check permissions.</source>
        <translation type="unfinished">No se puede abrir el archivo fuente. Chequee los permisos.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open destination file. Please check permissions.</source>
        <translation type="unfinished">No se puede abrir el archivo destino. Chequee los permisos.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Force: Cannot remove destination file.</source>
        <translation type="unfinished">No se puede eliminar el archivo destino.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create symbolic link targeting to source.</source>
        <translation type="unfinished">No se puede crear el link simbólico direccionado a la fuente.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot read source file.</source>
        <translation type="unfinished">No se puede leer el archivo.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot write destination file.</source>
        <translation type="unfinished">No se puede escribir el archivo destino.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot remove source.</source>
        <translation type="unfinished">No se puede eliminar la fuente.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>100% of %1 (Done)</source>
        <translation type="unfinished">100% de %1 (completado)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copying...</source>
        <translation type="unfinished">Copiando...</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1% of %2 (%3)</source>
        <translation type="unfinished">%1% de %2 (%3)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Done</source>
        <translation type="unfinished">Terminado</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation type="unfinished">Fuente</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation type="unfinished">Destino</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
</context>
<context>
    <name>QtOverwriteDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation type="unfinished">Advertencia</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation type="unfinished">Fuente</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation type="unfinished">Destino</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation type="unfinished">Descartar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Overwrite</source>
        <translation type="unfinished">Sobreescribir</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination already exists.</source>
        <translation type="unfinished">El destino ya existe.</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Preparing to delete %1 files</source>
        <translation type="unfinished">Preparándose para eliminar %1 archivos</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting %1</source>
        <translation type="unfinished">Eliminando %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Error deleting %1</source>
        <translation type="unfinished">Error eliminando %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Delete Finished Ok</source>
        <translation type="unfinished">Se terminó de eliminar con éxito</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Abort</source>
        <translation type="unfinished">Abortar</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting files</source>
        <translation type="unfinished">Borrando archivos</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Settings</source>
        <translation type="unfinished">Configuración</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Apply</source>
        <translation type="unfinished">Aplicar</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Home folder</source>
        <translation type="unfinished">Carpeta de inicio</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Icons Style</source>
        <translation type="unfinished">Estilo de íconos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Text Editor</source>
        <translation type="unfinished">Editor de texto</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable root access (restart needed)</source>
        <translation type="unfinished">Habilitar superusuario (necesita reiniciar)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show hidden files and folders</source>
        <translation type="unfinished">Mostrar archivos y carpetas ocultos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show thumbnails for images</source>
        <translation type="unfinished">Mostrar miniaturas para imágenes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show details for files</source>
        <translation type="unfinished">Mostrar detalles para archivos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Delete items from clipboard on Paste</source>
        <translation type="unfinished">Borrar ítems del Portapapeles al Pegar</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable multiselection</source>
        <translation type="unfinished">Habilitar multiselección</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Autoselect items in clipboard</source>
        <translation type="unfinished">Autoseleccionar ítems del portapapeles</translation>
    </message>
</context>
<context>
    <name>NewFolder</name>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Create folder</source>
        <translation type="unfinished">Creando carpeta</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Enter new folder name</source>
        <translation type="unfinished">Ingrese el nombre de la nueva carpeta</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cannot create folder. Try another name.</source>
        <translation type="unfinished">No se puede crear con ese nombre. Intente de nuevo.</translation>
    </message>
</context>
<context>
    <name>QtOtherDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Retry</source>
        <translation type="unfinished">Reintentar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation type="unfinished">Descartar</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation type="unfinished">Fuente</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Destination</source>
        <translation type="unfinished">Destino</translation>
    </message>
</context>
<context>
    <name>Rename</name>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Renaming</source>
        <translation type="unfinished">Renombrando</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Enter new name</source>
        <translation type="unfinished">Ingrese un nuevo nombre</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cannot rename. Try another name.</source>
        <translation type="unfinished">No se puede renombrar. Pruebe otro nombre.</translation>
    </message>
</context>
<context>
    <name>AskDialog</name>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Deleting</source>
        <translation type="unfinished">Borrando</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete %1?</source>
        <translation type="unfinished">Está seguro que desea borrar %1?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation type="unfinished">Está seguro que desea borrar los archivos seleccionados?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Yes</source>
        <translation type="unfinished">Si</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>No</source>
        <translation type="unfinished">No</translation>
    </message>
</context>
<context>
    <name>Sort</name>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Sort</source>
        <translation type="unfinished">Ordenar</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Ascending</source>
        <translation type="unfinished">Ascendente</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Descending</source>
        <translation type="unfinished">Descendente</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (A-Z)</source>
        <translation type="unfinished">Nombre (A-Z)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (Z-A)</source>
        <translation type="unfinished">Nombre (Z-A)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (olders first)</source>
        <translation type="unfinished">Fecha (viejos primero)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (recents first)</source>
        <translation type="unfinished">Fecha (recientes primero)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (smallers first)</source>
        <translation type="unfinished">Tamaño (pequeños primero)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (biggers first)</source>
        <translation type="unfinished">Tamaño (grandes primero)</translation>
    </message>
</context>
<context>
    <name>NewDoc</name>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>New document</source>
        <translation type="unfinished">Documento nuevo</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Create</source>
        <translation type="unfinished">Crear</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter name for new document</source>
        <translation type="unfinished">Ingrese nombre para el documento</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter a valid file name</source>
        <translation type="unfinished">Ingrese un nombre válido</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>The file already exists. Try another name</source>
        <translation type="unfinished">El archivo ya existe. Intente otro nombre</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cannot create the file. Check permissions</source>
        <translation type="unfinished">No se puede crear el documento. Chequee permisos</translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
</context>
<context>
    <name>CompressDlg</name>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compress</source>
        <translation type="unfinished">Comprimir</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>File name</source>
        <translation type="unfinished">Nombre del archivo</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compression</source>
        <translation type="unfinished">Compresión</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation type="unfinished">Carpeta destino</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>The file already exists. Try another name.</source>
        <translation type="unfinished">El archivo ya existe. Pruebe otro nombre.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>You don't have permissions to proceed.</source>
        <translation type="unfinished">No tiene permisos para proceder.</translation>
    </message>
</context>
<context>
    <name>Compress</name>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Compressing</source>
        <translation type="unfinished">Comprimiendo</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Adding %1...</source>
        <translation type="unfinished">Añadiendo %1...</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation type="unfinished">Operación terminada.</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
</context>
<context>
    <name>Unzip</name>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Extract files</source>
        <translation type="unfinished">Extraer archivos</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>You don't have permissions to proceed.</source>
        <translation type="unfinished">No tiene permisos para proceder.</translation>
    </message>
</context>
<context>
    <name>UnzipDlg</name>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Extract</source>
        <translation type="unfinished">Extraer</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation type="unfinished">Carpeta destino</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Keep existing files</source>
        <translation type="unfinished">Mantener archivos existentes</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>Extract</name>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting</source>
        <translation type="unfinished">Extrayendo</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting %1...</source>
        <translation type="unfinished">Extrayendo %1...</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation type="unfinished">Operación terminada.</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>About FileBox</source>
        <translation type="unfinished">Acerca de FileBox</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>File Manager for Maemo 5</source>
        <translation type="unfinished">Admin de archivos para Maemo 5</translation>
    </message>
</context>
</TS>
